import { from, of } from 'rxjs';
import {
  map, mergeMap, catchError
} from 'rxjs/operators';
import { ofType } from 'redux-observable';
import ActionTypes from '../../actions';
import {
  getEmrRelationship,
  getProfileData,
  editPhoto,
  deletePhoto
} from '../../services/personProfileService';

const getEmrRelationshipHandler = (response) => {
  if (response !== null) {
    return {
      type: ActionTypes.GET_PERSONPROFILE_EMRRELATIONSHIP_SUCCESS,
      payload: response
    };
  }
  throw response;
};

const editPhotoHandler = (response) => {
  if (response !== null) {
    return {
      type: ActionTypes.EDIT_PERSONALPHOTO_SUCCESS,
      payload: response
    };
  }
  throw response;
};

const deletePhotoHandler = (response) => {
  if (response !== null) {
    return {
      type: ActionTypes.DELETE_PERSONALPHOTO_SUCCESS,
      payload: response
    };
  }
  throw response;
};

const getProfileDataHandler = (response) => {
  if (response !== null) {
    return {
      type: ActionTypes.GET_PERSONPROFILE_PERSONALINFO_SUCCESS,
      payload: response
    };
  }
  throw response;
};

const editPhotoFailureHandler = error => ({
  type: ActionTypes.EDIT_PERSONALPHOTO_FAILURE,
  payload: error
});

const deletePhotoFailureHandler = error => ({
  type: ActionTypes.DELETE_PERSONALPHOTO_FAILURE,
  payload: error
});

const getEmrRelationshipFailureHandler = error => ({
  type: ActionTypes.GET_PERSONPROFILE_EMRRELATIONSHIP_FAILURE,
  payload: error
});

const getProfileDataFailureHandler = error => ({
  type: ActionTypes.GET_PERSONPROFILE_PERSONALINFO_FAILURE,
  payload: error
});

export const getEmrRelationshipEpic = action$ => action$.pipe(
  ofType(ActionTypes.GET_PERSONPROFILE_EMRRELATIONSHIP_REQUEST),
  mergeMap(() => from(getEmrRelationship()).pipe(
    map(response => getEmrRelationshipHandler(response)),
    catchError(error => of(getEmrRelationshipFailureHandler(error)))
  ))
);

export const getProfileDataEpic = action$ => action$.pipe(
  ofType(ActionTypes.GET_PERSONPROFILE_PERSONALINFO_REQUEST),
  mergeMap(() => from(getProfileData()).pipe(
    map(response => getProfileDataHandler(response)),
    catchError(error => of(getProfileDataFailureHandler(error)))
  ))
);

export const editPhotoEpic = action$ => action$.pipe(
  ofType(ActionTypes.EDIT_PERSONALPHOTO_REQUEST),
  mergeMap(action => from(editPhoto(action.payload.params)).pipe(
    map(response => editPhotoHandler(response)),
    catchError(error => of(editPhotoFailureHandler(error)))
  ))
);

export const deletePhotoEpic = action$ => action$.pipe(
  ofType(ActionTypes.DELETE_PERSONALPHOTO_REQUEST),
  mergeMap(() => from(deletePhoto()).pipe(
    map(response => deletePhotoHandler(response)),
    catchError(error => of(deletePhotoFailureHandler(error)))
  ))
);
